#! /usr/bin/env python
# -*- coding: utf-8 -*-
# vim:fenc=utf-8
#
# Copyright © 2018 zenbook <zenbook@zenbook-XPS>
#
# Distributed under terms of the MIT license.

"""

"""

from __future__ import print_function
import sys
import os
import re

if sys.version_info[0] == 3:
    from importlib import reload
    
os.chdir(os.path.dirname(os.path.abspath(__file__)))
SYS_PREFIX = os.path.dirname(os.path.dirname(sys.executable))+'/lib'

def reload_all():
    """Reload all non-system modules, so a pdb restart
    will reload anything new
    """
    # This is likely to be OS-specific
    os.path.dirname(os.path.dirname(sys.executable))

    for k, v in sys.modules.items():
        if not hasattr(v, '__file__'):
            continue
        elif v.__file__.startswith(SYS_PREFIX):
            continue
        elif k == '__main__':
            continue
        elif v.__file__ == __file__:
            continue
        elif re.match(".+\.pyc$", v.__file__):
            os.remove(v.__file__)
        print('reloading %s [%s]' % (k, v.__file__))
        reload(v)



#! /usr/bin/env python
# -*- coding: utf-8 -*-
# vim:fenc=utf-8
#
# Copyright © 2018 zenbook <zenbook@zenbook-XPS>
#

import unittest
import test_python_module
import reload_all
import os

class Test(unittest.TestCase):
    def setUp(self):
        pass


    def tearDown(self):
        pass


    def testName(self):
        os.chdir(os.path.dirname(os.path.abspath(__file__)))
        with open("foo_python_module.py", "w") as f:
            pass
        import foo_python_module
        reload_all.reload_all()
        with open("foo_python_module.py", "w") as f:
            f.write("print(\"reloaded\")")
        reload_all.reload_all()

if __name__ == '__main__':
    #import sys;sys.argv = ['', 'Test.testName']
    unittest.main()



#! /usr/bin/env python
# -*- coding: utf-8 -*-
# vim:fenc=utf-8
#
# Copyright © 2018 fx-kirin
#
# Distributed under terms of the MIT license.

"""

"""

try:
    from setuptools import setup, Extension
except ImportError:
    from distutils.core import setup, Extension
setup(
    name='reload_all',
    version='0.01',
    description='Reload all modules for 2.7 and 3.4+',
    long_description='',
    author='fx-kirin',
    author_email='ono.kirin@gmail.com',
    url='https://github.com/fx-kirin/pyreload_all',
    download_url='',
    packages=['']
)
